@@ -11,8 +11,8 @@ use tanoshi_vm::{bus::ExtensionBus, vm};
 #[clap(version = "0.1.1", author = "Muhammad Fadhlika <fadhlika@gmail.com>")]
 #[clap(setting = AppSettings::ColoredHelp)]
 struct Opts {
-    #[clap(long)]
-    path: Option<String>,
+    #[clap(short, long, default_value = "target/wasm32-wasi/release")]
+    path: String,
     #[clap(subcommand)]
     subcmd: SubCommand,
 }
@@ -45,33 +45,29 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     let opts: Opts = Opts::parse();
 
-    let extension_path = match opts.path {
-        Some(path) => path,
-        None => "target/wasm32-wasi/release".to_string(),
-    };
-
     let (_, extension_tx) = vm::start();
 
     #[cfg(not(feature = "disable-compiler"))]
     if !matches!(opts.subcmd, SubCommand::Compile(_)) {
-        vm::load(&extension_path, extension_tx.clone()).await?;
+        vm::load(&opts.path, extension_tx.clone()).await?;
     }
 
     #[cfg(feature = "disable-compiler")]
-    vm::load(&extension_path, extension_tx.clone()).await?;
+    vm::load(&opts.path, extension_tx.clone()).await?;
 
-    let extension_bus = ExtensionBus::new(extension_path.clone(), extension_tx);
+    let extension_bus = ExtensionBus::new(opts.path.clone(), extension_tx);
 
     match opts.subcmd {
         #[cfg(not(feature = "disable-compiler"))]
-        SubCommand::Compile(opts) => {
+        SubCommand::Compile(compile_opts) => {
             // let triples = [
             //     "x86_64-apple-darwin",
             //     "x86_64-pc-windows-msvc",
             //     "x86_64-unknown-linux-gnu",
             //     "aarch64-unknown-linux-gnu",
             // ];
-            vm::compile_with_target(&extension_path, &opts.target, opts.remove_wasm).await?;
+            vm::compile_with_target(&opts.path, &compile_opts.target, compile_opts.remove_wasm)
+                .await?;
         }
         SubCommand::GenerateJson => {
             generate::generate_json(extension_bus).await?;
